"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactNative = require("react-native");

var _reactNativeRootToast = _interopRequireDefault(require("react-native-root-toast"));

var _propTypes = _interopRequireDefault(require("prop-types"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const ClipboardToast = ({
  textToShow = '',
  textToCopy = '',
  toastText = 'Text is copied',
  containerStyle = {},
  textStyle = {},
  id = 'someKey',
  accessibilityLabel,
  toastDuration = 750,
  toastPosition,
  toastDelay = 0,
  toastAnimation = true,
  toastHideOnPress = true,
  toastBackgroundColor = null,
  toastTextColor = null,
  toastOnShow = () => {}
}) => {
  const convertPosition = () => {
    switch ((toastPosition || '').toLowerCase()) {
      case 'top':
        return _reactNativeRootToast.default.positions.TOP;

      case 'center':
        return _reactNativeRootToast.default.positions.CENTER;

      default:
        return _reactNativeRootToast.default.positions.BOTTOM;
    }
  };

  const onCopyToClipBoard = clipboardText => {
    _reactNative.Clipboard.setString(clipboardText);

    let toast = _reactNativeRootToast.default.show(toastText, {
      duration: _reactNativeRootToast.default.durations.LONG,
      position: convertPosition(),
      shadow: true,
      animation: toastAnimation,
      hideOnPress: toastHideOnPress,
      delay: toastDelay,
      backgroundColor: toastBackgroundColor,
      textColor: toastTextColor,
      onShow: toastOnShow
    });

    setTimeout(function () {
      _reactNativeRootToast.default.hide(toast);
    }, toastDuration + toastDelay);
  };

  return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    key: id,
    accessible: true,
    accessibilityRole: "text",
    accessibilityLabel: accessibilityLabel,
    style: containerStyle,
    onPress: () => onCopyToClipBoard(textToCopy)
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: textStyle
  }, textToShow));
};

ClipboardToast.propTypes = {
  textToShow: _propTypes.default.string.isRequired,
  textToCopy: _propTypes.default.string.isRequired,
  toastText: _propTypes.default.string.isRequired,
  containerStyle: _propTypes.default.any,
  textStyle: _propTypes.default.any,
  id: _propTypes.default.oneOfType([_propTypes.default.string, _propTypes.default.number]),
  accessibilityLabel: _propTypes.default.string,
  toastDuration: _propTypes.default.number,
  toastPosition: _propTypes.default.oneOf(['top', 'center', 'bottom']),
  toastDelay: _propTypes.default.number,
  toastAnimation: _propTypes.default.bool,
  toastHideOnPress: _propTypes.default.bool,
  toastBackgroundColor: _propTypes.default.any,
  toastTextColor: _propTypes.default.any,
  toastOnShow: _propTypes.default.func
};
var _default = ClipboardToast;
exports.default = _default;
//# sourceMappingURL=clipboard-toast.js.map